diff graal/com.oracle.truffle.api/src/com/oracle/truffle/api/tools/NodeExecCounter.java @ 19186:3d2296dbace9

Truffle/Instrumentation: TruffleTool renamed to InstrumentationTool (the base class for a group of tools that collect information during program execution)
author Michael Van De Vanter <michael.van.de.vanter@oracle.com>
date Sun, 08 Feb 2015 20:05:40 -0800
parents c7e57dffc5ad
children c5b20395a8bf
line wrap: on
line diff
--- a/graal/com.oracle.truffle.api/src/com/oracle/truffle/api/tools/NodeExecCounter.java	Sat Feb 07 02:47:00 2015 +0100
+++ b/graal/com.oracle.truffle.api/src/com/oracle/truffle/api/tools/NodeExecCounter.java	Sun Feb 08 20:05:40 2015 -0800
@@ -36,13 +36,13 @@
 import com.oracle.truffle.api.nodes.Node.Child;
 
 /**
  * A {@link TruffleTool} that counts interpreter <em>execution calls</em> to AST nodes, tabulated by
  * the type of called nodes; counting can be enabled <em>all</em> nodes or restricted to nodes with
  * a specified {@linkplain SyntaxTag tag} that is presumed to be applied external to the tool.
  * <p>
  * <b>Tool Life Cycle</b>
  * <p>
  * See {@link TruffleTool} for the life cycle common to all such tools.
  * </p>
  * <b>Execution Counts</b>
  * <p>
@@ -79,7 +79,7 @@
  * @see SyntaxTag
  * @see ProbeFailure
  */
-public final class NodeExecCounter extends TruffleTool {
+public final class NodeExecCounter extends InstrumentationTool {
 
     /**
      * Execution count for AST nodes of a particular type.
@@ -36,13 +36,13 @@
 
 /**
- * A {@link TruffleTool} that counts interpreter <em>execution calls</em> to AST nodes, tabulated by
+ * A {@link InstrumentationTool} that counts interpreter <em>execution calls</em> to AST nodes, tabulated by
  * the type of called nodes; counting can be enabled <em>all</em> nodes or restricted to nodes with
  * a specified {@linkplain SyntaxTag tag} that is presumed to be applied external to the tool.
@@ -36,13 +36,13 @@
  * <b>Tool Life Cycle</b>
  * <p>
- * See {@link TruffleTool} for the life cycle common to all such tools.
+ * See {@link InstrumentationTool} for the life cycle common to all such tools.
  * </p>
  * <b>Execution Counts</b>